@@ -23,21 +23,26 @@ Facter.add(:domain) do
     # Get the domain from various sources; the order of these
     # steps is important
 
-    # In some OS 'hostname -f' will change the hostname to '-f' 
-    # We know that Solaris and HP-UX exhibit this behavior 
-    # On good OS, 'hostname -f' will return the FQDN which is preferable 
-    # Due to dangerous behavior of 'hostname -f' on old OS, we will explicitly opt-in 
+    # In some OS 'hostname -f' will change the hostname to '-f'
+    # We know that Solaris and HP-UX exhibit this behavior
+    # On good OS, 'hostname -f' will return the FQDN which is preferable
+    # Due to dangerous behavior of 'hostname -f' on old OS, we will explicitly opt-in
     # 'hostname -f' --hkenney May 9, 2012
-    hostname_command = 'hostname'
+    basic_hostname = 'hostname 2> /dev/null'
+    full_hostname = 'hostname -f 2> /dev/null'
     can_do_hostname_f = Regexp.union /Linux/i, /FreeBSD/i, /Darwin/i
-    hostname_command = 'hostname -f' if Facter.value(:kernel) =~ can_do_hostname_f
 
-       
+    hostname_command = if Facter.value(:kernel) =~ can_do_hostname_f
+                         full_hostname
+                       else
+                         basic_hostname
+                       end
+
     if name = Facter::Util::Resolution.exec(hostname_command) \
       and name =~ /.*?\.(.+$)/
 
       return_value = $1
-    elsif domain = Facter::Util::Resolution.exec('dnsdomainname') \
+    elsif domain = Facter::Util::Resolution.exec('dnsdomainname 2> /dev/null') \
       and domain =~ /.+/
 
       return_value = domain
